import requests
from bs4 import BeautifulSoup

NCBI_BASE_URL = 'https://www.ncbi.nlm.nih.gov'
QUERY_KEY = '[name="EntrezSystem2.PEntrez.Protein.Sequence_ResultsPanel.Sequence_DisplayBar.QueryKey"]'


def ncbi_download_accids(**kwargs):
    term = kwargs.get('term')
    res1 = requests.get(f'{NCBI_BASE_URL}/protein/?term={term}')
    soup = BeautifulSoup(res1.text, 'html.parser')
    query_key_el = soup.select_one(QUERY_KEY)
    query_key = query_key_el.attrs['value']
    res2 = requests.get(f'{NCBI_BASE_URL}/sviewer/viewer.cgi?db=protein&report=accnlist&query_key={query_key}',
                        cookies=res1.cookies)

    result = []
    for acc in res2.text.split('\n'):
        if acc:
            result.append(acc)
    return result



import jsw_nx as nx


def url(in_id, in_report, **kwargs):
    ext_opts = dict(kwargs)
    opts = nx.mix({'db': 'protein', 'retmode': 'text', 'report': in_report}, ext_opts)
    param = nx.param(opts)
    return f'https://www.ncbi.nlm.nih.gov/sviewer/viewer.fcgi?id={in_id}&{param}'



import nltk


def keyword(in_string, **kwargs):
    sentences = nltk.sent_tokenize(in_string)
    selector = kwargs.get('selector', lambda item: 'NNP' == item[1])
    callback = kwargs.get('callback', lambda item: item[0].lower())
    res = []
    data = []

    for sent in sentences:
        data = data + nltk.pos_tag(nltk.word_tokenize(sent))
    for word in data:
        if selector(word):
            res.append(callback(word))

    return res



import pkg_resources

version = pkg_resources.get_distribution('jsw-bio').version
__version__ = version

# next base
from jsw_bio.base.url import url
from jsw_bio.base.keyword import keyword
from jsw_bio.ncbi.ncbi_download_accids import ncbi_download_accids



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['jsw_bio', 'jsw_bio.base', 'jsw_bio.ncbi']

package_data = \
{'': ['*']}

install_requires = \
['bs4>=0.0.1,<0.0.2',
 'jsw-nx>=1.0.92,<2.0.0',
 'nltk>=3.7,<4.0',
 'psutil>=5.9.0,<6.0.0',
 'requests>=2.27.1,<3.0.0']

setup_kwargs = {
    'name': 'jsw-bio',
    'version': '1.0.4',
    'description': 'Jsw for biography.',
    'long_description': "# jsw-bio\n> Jsw for biography.\n\n## installation\n```shell\npip install jsw-bio -U\n```\n\n## usage\n```python\nimport jsw_bio as bio\n\n## common methods\n# get fasta/genbank url\nbio.url('7EU9_A', 'fasta')\nbio.url('7EU9_A', 'gb')\nbio.ncbi_download_accids(term='cas12') # ['VEJ66715.1', 'SUY72866.1', 'SUY81473.1', ...\n```\n",
    'author': 'feizheng',
    'author_email': '1290657123@qq.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://js.work',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
